@@ -1,17 +1,23 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import absolute_import
 import base64
+import sys
+
+if sys.version_info[0] == 3:
+    ord = lambda i: i
 
 
 def b64_encode(source):
-    if isinstance(source, str):
+    if not isinstance(source, bytes):
         source = source.encode('ascii')
 
-    return base64.urlsafe_b64encode(source).replace(b'=', b'').decode('ascii')
+    encoded = base64.urlsafe_b64encode(source).replace(b'=', b'')
+    return str(encoded.decode('ascii'))
 
 
 def b64_decode(source):
-    if isinstance(source, str):
+    if not isinstance(source, bytes):
         source = source.encode('ascii')
 
     source += b'=' * (4 - (len(source) % 4))
@@ -19,12 +25,12 @@ def b64_decode(source):
 
 
 def base64_to_int(source):
-    if isinstance(source, str):
+    if not isinstance(source, bytes):
         source = source.encode('ascii')
 
     result = 0
     for b in b64_decode(source):
-        result = (result << 8) + b
+        result = (result << 8) + ord(b)
 
     return result
 
@@ -35,4 +41,4 @@ def int_to_base64(source):
         source, remainder = divmod(source, 256)
         result_reversed.append(remainder)
 
-    return b64_encode(bytes(reversed(result_reversed)))
+    return b64_encode(bytes(bytearray(reversed(result_reversed))))
